# This emulator doesn't require copyrighted data (e.g. console BIOS)
# to function, it can thus go in core.

Summary:        Sony PlayStation Portable (PSP) emulator
Name:           ppsspp
Version:        1.14.4
Release:        %mkrel 5
License:        GPLv2+
Group:          Emulators
Url:            https://www.ppsspp.org
# git clone https://github.com/hrydgard/ppsspp && cd ppsspp
# git submodule update --init --recursive assets/lang ext/SPIRV-Cross ext/armips ext/discord-rpc ext/glslang ext/zstd ext/miniupnp ext/cpu_features ffmpeg
# Edit .gitmodules to comment out the ones not use, or git archive-all will fail.
# Remove each ffmpeg build (android, Windows10 ...)
# git archive-all --prefix=ppsspp-%%{version}/ ppsspp-%%{version}.tar.xz
Source0:        %{name}-%{version}.tar.xz
# Patch1:         ppsspp-1.10.3-git-version.patch
Patch2:         ppsspp-1.7.2-mga-system-rapidjson.patch

BuildRequires:  cmake
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
# Needs libpng 1.7+, not packaged in mga7 for now
#BuildRequires:  pkgconfig(libpng) >= 1.7
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(snappy)
BuildRequires:  pkgconfig(zlib)
# TODO: Try to unbundle glslang now that we package it.

%ifarch %{arm}
BuildRequires:  libatomic-devel
BuildRequires:  pkgconfig(egl)
%endif

Provides:   bundled(ffmpeg)=3.1

%description
PPSSPP is a cross-platform Sony PlayStation Portable (PSP) emulator.

PPSSPP can run your PSP games on your PC in full HD resolution, and play
them on Android too. It can even upscale textures that would otherwise be
too blurry as they were made for the small screen of the original PSP.

%files
%doc LICENSE.TXT README.md
%{_datadir}/applications/%{name}.desktop
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}.png

#----------------------------------------------------------------------------

%prep
%autosetup -p1

# Fix version string
sed s,"unknown_version","%{version}-%{release}",g -i git-version.cmake

# Make sure those are not used
rm -rf ext/zlib
rm -rf ext/native/ext/libzip
#rm -rf ext/native/ext/libpng17
# We need to keep the CMakeLists.txt for USE_SYSTEM_SNAPPY and GLEW_FOUND
rm -rf ext/glew/{GL,*.c}
rm -rf ext/snappy/*.{cpp,h}

%build
pushd ffmpeg
export CFLAGS="%{optflags} -fPIC"
export LDFLAGS="%{ldflags}"

./configure  --target-os=linux \
    --arch=${_arch} \
    --prefix=./linux \
    --disable-shared \
    --enable-static \
    --enable-zlib \
    --disable-everything \
   --disable-avdevice \
   --disable-filters \
   --disable-programs \
   --disable-network \
   --disable-avfilter \
   --disable-postproc \
   --disable-encoders \
   --disable-protocols \
   --disable-hwaccels \
   --disable-doc \
    --disable-yasm \
    --disable-ffplay \
    --disable-ffprobe \
    --disable-ffserver \
    --disable-ffmpeg \
   --enable-decoder=h264 \
   --enable-decoder=mpeg4 \
   --enable-decoder=mpeg2video \
   --enable-decoder=mjpeg \
   --enable-decoder=mjpegb \
    --enable-decoder=aac \
    --enable-decoder=aac_latm \
    --enable-decoder=atrac3 \
    --enable-decoder=atrac3p \
    --enable-decoder=mp3 \
    --enable-decoder=pcm_s16le \
    --enable-decoder=pcm_s8 \
    --enable-demuxer=h264 \
    --enable-demuxer=m4v \
    --enable-demuxer=mpegvideo \
    --enable-demuxer=mpegps \
    --enable-demuxer=mp3 \
    --enable-demuxer=avi \
    --enable-demuxer=aac \
    --enable-demuxer=pmp \
    --enable-demuxer=oma \
    --enable-demuxer=pcm_s16le \
    --enable-demuxer=pcm_s8 \
    --enable-demuxer=wav \
	  --enable-encoder=huffyuv \
	  --enable-encoder=ffv1 \
	  --enable-encoder=mjpeg \
	  --enable-encoder=pcm_s16le\
  	  --enable-muxer=avi\
    --enable-parser=h264 \
    --enable-parser=mpeg4video \
    --enable-parser=mpegaudio \
    --enable-parser=mpegvideo \
    --enable-parser=aac \
    --enable-parser=aac_latm
make clean
make install
popd
%cmake \
  -DBUILD_SHARED_LIBS=OFF \
  -DHEADLESS=OFF \
  -DUSE_FFMPEG=ON \
  -DFFMPEG_DIR=ffmpeg/linux \
  -DUSE_SYSTEM_FFMPEG=OFF \
  -DUSE_SYSTEM_LIBZIP=ON \
  -DUSE_SYSTEM_SNAPPY=ON \
%ifarch %{arm}
  -DARMV7:BOOL=ON \
%endif

%cmake_build

%install
# no make install for ppsspp, only for its bundled deps
install -D -m755 %{_vpath_builddir}/PPSSPPSDL %{buildroot}%{_gamesbindir}/%{name}

install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -a build/assets %{buildroot}%{_gamesdatadir}/%{name}

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Type=Application
Name=PPSSPP
GenericName=PSP Emulator
Comment=PlayStation Portable Simulator Suitable for Playing Portably (PPSSPP)
Exec=ppsspp %f
Icon=ppsspp
Categories=Game;Emulator;
EOF

install -d %{buildroot}%{_iconsdir}
cp -a icons/hicolor %{buildroot}%{_iconsdir}


%changelog
* Thu Apr 06 2023 papoteur <papoteur> 1.14.4-5.mga9
+ Revision: 1951545
- add BR for build for ARM

* Wed Apr 05 2023 papoteur <papoteur> 1.14.4-4.mga9
+ Revision: 1951497
- add atomic library for armv7

* Wed Apr 05 2023 papoteur <papoteur> 1.14.4-3.mga9
+ Revision: 1951496
- rebuild with options for armv7

* Wed Apr 05 2023 papoteur <papoteur> 1.14.4-2.mga9
+ Revision: 1951490
- cleaned tarball
- build bundled ffmpeg

* Tue Apr 04 2023 papoteur <papoteur> 1.14.4-1.mga9
+ Revision: 1951392
- new 1.14.4
- embed ffmpeg 3 because ppsspp will not be migrated to ffmpeg 5
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1.10.3-2.mga8
+ Revision: 1651615
- rebuild for glew

* Fri Oct 23 2020 akien <akien> 1.10.3-1.mga8
+ Revision: 1638977
- Version 1.10.3

* Sat Jun 27 2020 akien <akien> 1.10-2.mga8
+ Revision: 1599653
- Add patch to fix armv7hl build

* Sat Jun 27 2020 akien <akien> 1.10-1.mga8
+ Revision: 1599606
- Version 1.10
- Now packaged in core, as it doesn't depend on copyrighted binary blobs.

* Fri Feb 21 2020 umeabot <umeabot> 1.9.3-3.mga8.tainted
+ Revision: 1548885
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Oct 07 2019 akien <akien> 1.9.3-2.mga8.tainted
+ Revision: 1450396
- Version 1.9.3

* Fri Apr 26 2019 akien <akien> 1.8.0-1.mga7.tainted
+ Revision: 1395381
- Version 1.8.0

* Wed Dec 12 2018 akien <akien> 1.7.5-1.mga7.tainted
+ Revision: 1340404
- Version 1.7.5

* Wed Nov 07 2018 akien <akien> 1.7.2-5.mga7.tainted
+ Revision: 1328770
- Use less intrusive hack to workaround GH-11490

* Tue Nov 06 2018 akien <akien> 1.7.2-4.mga7.tainted
+ Revision: 1328677
- Attempt fixing linking issue on armv7hl (https://github.com/hrydgard/ppsspp/issues/11539)

* Tue Nov 06 2018 akien <akien> 1.7.2-3.mga7.tainted
+ Revision: 1328671
- Revert upstream commit to workaround choppy videos https://github.com/hrydgard/ppsspp/issues/11490

* Tue Nov 06 2018 akien <akien> 1.7.2-2.mga7.tainted
+ Revision: 1328667
- Link OpenGL properly also on ARM/EGL

* Tue Nov 06 2018 akien <akien> 1.7.2-1.mga7.tainted
+ Revision: 1328645
- Version 1.7.2 (fixes mga#20566)

* Thu Sep 20 2018 umeabot <umeabot> 1.6.3-2.mga7.tainted
+ Revision: 1288055
- Mageia 7 Mass Rebuild
+ akien <akien>
- Version 1.6.3

* Mon May 14 2018 akien <akien> 1.5.4-1.mga7.tainted
+ Revision: 1229475
- Version 1.5.4

* Sun Apr 29 2018 daviddavid <daviddavid> 1.4.2-5.mga7.tainted
+ Revision: 1223639
- add upstream patch to fix build with ffmpeg 4.0
- rebuild for new ffmpeg 4.0

* Sat Dec 30 2017 wally <wally> 1.4.2-4.mga7.tainted
+ Revision: 1187974
- rebuild for new libzip

* Sun Dec 03 2017 daviddavid <daviddavid> 1.4.2-3.mga7.tainted
+ Revision: 1180814
- rebuild for new glew 2.1.0

* Tue Sep 05 2017 cjw <cjw> 1.4.2-2.mga7.tainted
+ Revision: 1151542
- rebuild for new libglew

* Sat Jun 03 2017 akien <akien> 1.4.2-1.mga6.tainted
+ Revision: 1106322
- Version 1.4.2
- Switch to cmake/SDL2 build (no longer Qt5)

* Wed Mar 08 2017 akien <akien> 1.3-2.mga6.tainted
+ Revision: 1090240
- Rebuild for ffmpeg 3.2.4

* Tue Nov 01 2016 akien <akien> 1.3-1.mga6.tainted
+ Revision: 1064685
- Version 1.3

* Tue May 24 2016 akien <akien> 1.2.2-4.mga6.tainted
+ Revision: 1018128
- Disable exit(0) call on quit that causes a segfault in QXcbEventReader

* Sun May 22 2016 akien <akien> 1.2.2-3.mga6.tainted
+ Revision: 1017548
- Upstream patch to fix tiny window size bug

* Fri Apr 01 2016 akien <akien> 1.2.2-2.mga6
+ Revision: 997485
- Version 1.2.2

* Mon Jan 11 2016 akien <akien> 1.1.1-2.mga6.tainted
+ Revision: 921457
- Fix broken desktop file
- Version 1.1.1
  o Drop Patch1 as upstream now handles the unbundling fine

* Thu Nov 19 2015 daviddavid <daviddavid> 1.0.1-4.mga6.tainted
+ Revision: 904222
- rebuild for new libzip 1.0.1

* Mon Aug 24 2015 sander85 <sander85> 1.0.1-3.mga6.tainted
+ Revision: 869152
- Rebuild for glew 1.13.0

* Wed Jun 24 2015 akien <akien> 1.0.1-2.mga6.tainted
+ Revision: 842034
- Rebuild for GLEW 1.12

* Tue Mar 10 2015 akien <akien> 1.0.1-1.mga5.tainted
+ Revision: 818295
- Version 1.0.1
  o Upstream support for system ffmpeg with Atrac3+ playback
    (ROSA patch has therefore been dropped)
  o Uses SDL2 instead of SDL
- Unbundled external libraries: glew, libzip, snappy and zlib

* Fri Nov 14 2014 akien <akien> 0.9.9.1-5.mga5.tainted
+ Revision: 797090
- Rebuild for ffmpeg 2.4

* Sun Nov 02 2014 akien <akien> 0.9.9.1-4.mga5.tainted
+ Revision: 795220
- Add a patch from Andrey Bondrov (ROSA) to fix Atrac3+ playback with system ffmpeg

* Wed Oct 15 2014 umeabot <umeabot> 0.9.9.1-3.mga5.tainted
+ Revision: 741090
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.9.1-2.mga5.tainted
+ Revision: 687762
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 akien <akien> 0.9.9.1-1.mga5.tainted
+ Revision: 674204
- Bugfix release 0.9.9.1
- Switch to qmake/Qt5 build instead of cmake/SDL one
- Use upstream option to use shared ffmpeg

* Wed Jul 30 2014 akien <akien> 0.9.9-1.mga5.tainted
+ Revision: 658359
- Version 0.9.9
- Drop OpenMandriva controls patch, it seems better to stick to upstream choices
- Install hicolor icons provided by upstream

* Mon Mar 24 2014 akien <akien> 0.9.7.2-2.mga5.tainted
+ Revision: 607812
- Rebuild for ffmpeg 2.2 (and in the proper section)
- Add a comment signaling this should be pushed to tainted

* Wed Feb 19 2014 akien <akien> 0.9.7.2-1.mga5
+ Revision: 594856
- New version 0.9.7.2: fixing a drastic slowdowns in a couple of games
- Changelog for 0.9.7.1: https://raw2.github.com/hrydgard/ppsspp/v0.9.7.1/README.md
- Import ppsspp SRPM from OpenMandriva


* Sun Feb 16 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 0.9.7.1-1
+ Revision: e3f1d04
- LOG New version 0.9.7.1, re-diff controls patch


